History
-------

2.1.1
+++++
released 2022-03-18

- Add missing history notes

2.1.0
+++++
released 2022-03-18

- Add support for Python 3.5 and 3.7

2.0.0
+++++
released 2016-07-15

- breaking: drop python 2.6 support
- fix a bug affecting operations after exiting a namespace
- add strict_missing and strict_missing_exception options

1.1.1
+++++
released 2014-09-26

- pin bidict to 0.1.5 to avoid breaking changes in newer versions

1.1.0
+++++
released 2014-07-28

- add schema for braintree.ClientToken.generate

1.0.1
+++++
released 2014-04-08

- use less expensive introspection
- remove decorator dependency

1.0.0
+++++
released 2014-04-07

- initial release
